==> twilight-http-0.8.5.crate: twilight-http-0.8.5/src/request/guild/mod.rs <==
pub mod ban;
pub mod create_guild;
pub mod create_guild_channel;
pub mod create_guild_prune;
pub mod emoji;
pub mod get_audit_log;
pub mod get_guild_prune_count;
pub mod integration;
pub mod member;
pub mod role;
pub mod sticker;
pub mod update_current_member;
pub mod update_guild;
pub mod update_guild_channel_positions;
pub mod user;

mod delete_guild;
mod get_active_threads;
mod get_guild;
mod get_guild_channels;
mod get_guild_invites;
mod get_guild_preview;
mod get_guild_vanity_url;
mod get_guild_voice_regions;
mod get_guild_webhooks;
mod get_guild_welcome_screen;
mod get_guild_widget;
mod update_current_user_nick;
mod update_guild_welcome_screen;
mod update_guild_widget;

pub use self::{
    create_guild::CreateGuild, create_guild_channel::CreateGuildChannel,
    create_guild_prune::CreateGuildPrune, delete_guild::DeleteGuild,
    get_active_threads::GetActiveThreads, get_audit_log::GetAuditLog, get_guild::GetGuild,
    get_guild_channels::GetGuildChannels, get_guild_invites::GetGuildInvites,
    get_guild_preview::GetGuildPreview, get_guild_prune_count::GetGuildPruneCount,
    get_guild_vanity_url::GetGuildVanityUrl, get_guild_voice_regions::GetGuildVoiceRegions,
    get_guild_webhooks::GetGuildWebhooks, get_guild_welcome_screen::GetGuildWelcomeScreen,
    get_guild_widget::GetGuildWidget, update_current_member::UpdateCurrentMember,
    update_guild::UpdateGuild, update_guild_channel_positions::UpdateGuildChannelPositions,
    update_guild_welcome_screen::UpdateGuildWelcomeScreen, update_guild_widget::UpdateGuildWidget,
};

#[deprecated(note = "use UpdateCurrentMember instead", since = "0.7.2")]
pub type UpdateCurrentUserNick<'a> = self::update_current_user_nick::UpdateCurrentUserNick<'a>;

==> twilight-http-0.9.1.crate: twilight-http-0.9.1/src/request/guild/mod.rs <==
pub mod ban;
pub mod create_guild;
pub mod emoji;
pub mod integration;
pub mod member;
pub mod role;
pub mod sticker;
pub mod update_guild_channel_positions;
pub mod user;

mod create_guild_channel;
mod create_guild_prune;
mod delete_guild;
mod get_active_threads;
mod get_audit_log;
mod get_guild;
mod get_guild_channels;
mod get_guild_invites;
mod get_guild_preview;
mod get_guild_prune_count;
mod get_guild_vanity_url;
mod get_guild_voice_regions;
mod get_guild_webhooks;
mod get_guild_welcome_screen;
mod get_guild_widget;
mod update_current_member;
mod update_guild;
mod update_guild_welcome_screen;
mod update_guild_widget;

pub use self::{
    create_guild::CreateGuild, create_guild_channel::CreateGuildChannel,
    create_guild_prune::CreateGuildPrune, delete_guild::DeleteGuild,
    get_active_threads::GetActiveThreads, get_audit_log::GetAuditLog, get_guild::GetGuild,
    get_guild_channels::GetGuildChannels, get_guild_invites::GetGuildInvites,
    get_guild_preview::GetGuildPreview, get_guild_prune_count::GetGuildPruneCount,
    get_guild_vanity_url::GetGuildVanityUrl, get_guild_voice_regions::GetGuildVoiceRegions,
    get_guild_webhooks::GetGuildWebhooks, get_guild_welcome_screen::GetGuildWelcomeScreen,
    get_guild_widget::GetGuildWidget, update_current_member::UpdateCurrentMember,
    update_guild::UpdateGuild, update_guild_channel_positions::UpdateGuildChannelPositions,
    update_guild_welcome_screen::UpdateGuildWelcomeScreen, update_guild_widget::UpdateGuildWidget,
};
